@@ -37,6 +37,7 @@ describe 'neutron::agents::ml2::ovs' do
     end
 
     it 'configures plugins/ml2/openvswitch_agent.ini' do
+      should contain_neutron_agent_ovs('ovs/bridge_mappings').with_ensure('absent')
       should contain_neutron_agent_ovs('agent/polling_interval').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('agent/report_interval').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('DEFAULT/rpc_response_max_timeout').with_value('<SERVICE DEFAULT>')
@@ -49,6 +50,8 @@ describe 'neutron::agents::ml2::ovs' do
       should contain_neutron_agent_ovs('ovs/datapath_type').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('ovs/vhostuser_socket_dir').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('ovs/ovsdb_timeout').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovs('ovs/of_listen_address').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovs('ovs/of_listen_port').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('ovs/of_connect_timeout').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('ovs/of_request_timeout').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('ovs/of_inactivity_probe').with_value('<SERVICE DEFAULT>')
@@ -181,19 +184,23 @@ describe 'neutron::agents::ml2::ovs' do
       end
 
       it 'configures bridge mappings' do
-        should contain_neutron_agent_ovs('ovs/bridge_mappings')
+        should contain_neutron_agent_ovs('ovs/bridge_mappings').with_value(params[:bridge_mappings].join(','))
       end
 
       it 'should configure bridge mappings' do
-        should contain_neutron__plugins__ovs__bridge(params[:bridge_mappings].join(',')).with(
-          :before => 'Service[neutron-ovs-agent-service]'
-        )
+        params[:bridge_mappings].each do |bridge_mapping|
+          should contain_neutron__plugins__ovs__bridge(bridge_mapping).with(
+            :before => 'Service[neutron-ovs-agent-service]'
+          )
+        end
       end
 
       it 'should configure bridge uplinks' do
-        should contain_neutron__plugins__ovs__port(params[:bridge_uplinks].join(',')).with(
-          :before => 'Service[neutron-ovs-agent-service]'
-        )
+        params[:bridge_uplinks].each do |bridge_uplink|
+          should contain_neutron__plugins__ovs__port(bridge_uplink).with(
+            :before => 'Service[neutron-ovs-agent-service]'
+          )
+        end
       end
     end
 
@@ -207,19 +214,52 @@ describe 'neutron::agents::ml2::ovs' do
       end
 
       it 'configures bridge mappings' do
-        should contain_neutron_agent_ovs('ovs/bridge_mappings')
+        should contain_neutron_agent_ovs('ovs/bridge_mappings').with_value(params[:bridge_mappings].join(','))
       end
 
       it 'should not configure bridge mappings' do
-        should_not contain_neutron__plugins__ovs__bridge(params[:bridge_mappings].join(',')).with(
-          :before => 'Service[neutron-ovs-agent-service]'
-        )
+        params[:bridge_mappings].each do |bridge_mapping|
+          should_not contain_neutron__plugins__ovs__bridge(bridge_mapping)
+        end
       end
 
       it 'should not configure bridge uplinks' do
-        should_not contain_neutron__plugins__ovs__port(params[:bridge_uplinks].join(',')).with(
-          :before => 'Service[neutron-ovs-agent-service]'
-        )
+        params[:bridge_uplinks].each do |bridge_uplink|
+          should_not contain_neutron__plugins__ovs__port(bridge_uplink)
+        end
+      end
+    end
+
+    context 'when supplying multiple bridge mappings' do
+      before :each do
+        params.merge!({
+          :bridge_uplinks  => ['br-ex:eth2','br-tenant:eth3'],
+          :bridge_mappings => ['default:br-ex','tenant:br-tenant'],
+        })
+      end
+
+      it 'should require vswitch::ovs' do
+        should contain_class('vswitch::ovs')
+      end
+
+      it 'configures bridge mappings' do
+        should contain_neutron_agent_ovs('ovs/bridge_mappings').with_value(params[:bridge_mappings].join(','))
+      end
+
+      it 'should configure bridge mappings' do
+        params[:bridge_mappings].each do |bridge_mapping|
+          should contain_neutron__plugins__ovs__bridge(bridge_mapping).with(
+            :before => 'Service[neutron-ovs-agent-service]'
+          )
+        end
+      end
+
+      it 'should configure bridge uplinks' do
+        params[:bridge_uplinks].each do |bridge_uplink|
+          should contain_neutron__plugins__ovs__port(bridge_uplink).with(
+            :before => 'Service[neutron-ovs-agent-service]'
+          )
+        end
       end
     end
 
@@ -233,10 +273,29 @@ describe 'neutron::agents::ml2::ovs' do
       end
     end
 
+    context 'when setting of_listen_address and of_listen_port' do
+      before :each do
+        params.merge!(
+          :of_listen_address => '127.0.0.1',
+          :of_listen_port    => 6633,
+        )
+      end
+
+      it 'configures of_listen_address' do
+        should contain_neutron_agent_ovs('ovs/of_listen_address').with_value(params[:of_listen_address])
+      end
+
+      it 'configures of_listen_port' do
+        should contain_neutron_agent_ovs('ovs/of_listen_port').with_value(params[:of_listen_port])
+      end
+    end
+
     context 'when setting of_connect_timeout and of_request_timeout' do
       before :each do
-        params.merge!( :of_connect_timeout => 30,
-                       :of_request_timeout => 20 )
+        params.merge!(
+          :of_connect_timeout => 30,
+          :of_request_timeout => 20
+        )
       end
 
       it 'configures of_connect_timeout' do
@@ -495,7 +554,7 @@ describe 'neutron::agents::ml2::ovs' do
       end
 
       let (:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :ovs_agent_package => 'neutron-openvswitch-agent',
             :ovs_agent_service => 'neutron-openvswitch-agent' }
@@ -508,7 +567,7 @@ describe 'neutron::agents::ml2::ovs' do
       end
 
       it_behaves_like 'neutron plugin ovs agent with ml2 plugin'
-      it_behaves_like "neutron::agents::ml2::ovs on #{facts[:osfamily]}"
+      it_behaves_like "neutron::agents::ml2::ovs on #{facts[:os]['family']}"
     end
   end
 end
