@@ -19,8 +19,6 @@ describe 'neutron::server' do
       :auth_strategy            => 'keystone',
       :sync_db                  => false,
       :router_scheduler_driver  => 'neutron.scheduler.l3_agent_scheduler.ChanceScheduler',
-      :l3_ha                    => false,
-      :max_l3_agents_per_router => 3,
     }
   end
 
@@ -131,13 +129,18 @@ describe 'neutron::server' do
 
     context 'with HA routers enabled' do
       before :each do
-        params.merge!(:l3_ha => true)
+        params.merge!(
+          :l3_ha                    => true,
+          :max_l3_agents_per_router => 3,
+        )
       end
 
       it 'should enable HA routers' do
         should contain_neutron_config('DEFAULT/l3_ha').with_value(true)
         should contain_neutron_config('DEFAULT/max_l3_agents_per_router').with_value(3)
         should contain_neutron_config('DEFAULT/l3_ha_net_cidr').with_value('<SERVICE DEFAULT>')
+        should contain_neutron_config('DEFAULT/l3_ha_network_type').with_value('<SERVICE DEFAULT>')
+        should contain_neutron_config('DEFAULT/l3_ha_network_physical_name').with_value('<SERVICE DEFAULT>')
       end
     end
 
@@ -148,15 +151,19 @@ describe 'neutron::server' do
 
       it 'should disable HA routers' do
         should contain_neutron_config('DEFAULT/l3_ha').with_value(false)
-        should contain_neutron_config('DEFAULT/max_l3_agents_per_router').with_value(3)
+        should contain_neutron_config('DEFAULT/max_l3_agents_per_router').with_value('<SERVICE DEFAULT>')
         should contain_neutron_config('DEFAULT/l3_ha_net_cidr').with_value('<SERVICE DEFAULT>')
+        should contain_neutron_config('DEFAULT/l3_ha_network_type').with_value('<SERVICE DEFAULT>')
+        should contain_neutron_config('DEFAULT/l3_ha_network_physical_name').with_value('<SERVICE DEFAULT>')
       end
     end
 
     context 'with HA routers enabled with unlimited l3 agents per router' do
       before :each do
-        params.merge!(:l3_ha                    => true,
-                      :max_l3_agents_per_router => 0 )
+        params.merge!({
+          :l3_ha                    => true,
+          :max_l3_agents_per_router => 0
+        })
       end
 
       it 'should enable HA routers' do
@@ -164,6 +171,20 @@ describe 'neutron::server' do
       end
     end
 
+    context 'with HA routers options' do
+      before :each do
+        params.merge!({
+          :l3_ha_network_type          => 'vlan',
+          :l3_ha_network_physical_name => 'datacentre'
+        })
+      end
+
+      it 'should configure the HA routers options' do
+        should contain_neutron_config('DEFAULT/l3_ha_network_type').with_value('vlan')
+        should contain_neutron_config('DEFAULT/l3_ha_network_physical_name').with_value('datacentre')
+      end
+    end
+
     context 'with allow_automatic_l3agent_failover in neutron.conf' do
       it 'should configure allow_automatic_l3agent_failover' do
         should contain_neutron_config('DEFAULT/allow_automatic_l3agent_failover').with_value('<SERVICE DEFAULT>')
@@ -375,9 +396,9 @@ describe 'neutron::server' do
       end
 
       let (:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
-          if facts[:operatingsystem] == 'Ubuntu'
+          if facts[:os]['name'] == 'Ubuntu'
             {
               :server_package   => 'neutron-server',
               :server_service   => 'neutron-server',
@@ -399,7 +420,7 @@ describe 'neutron::server' do
 
       it_behaves_like 'a neutron server'
       it_behaves_like 'a neutron server without database synchronization'
-      it_behaves_like "neutron server dynamic routing on #{facts[:osfamily]}"
+      it_behaves_like "neutron server dynamic routing on #{facts[:os]['family']}"
     end
   end
 end
