@@ -83,7 +83,7 @@ describe 'neutron::services::sfc' do
       end
 
       let (:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :sfc_package_name => 'python3-networking-sfc' }
         when 'RedHat'
